@@ -15,11 +15,13 @@ from typing import Any
 from beartype import beartype
 from icontract import ensure, require
 
+from specfact_cli import runtime
 from specfact_cli.analyzers.constitution_evidence_extractor import ConstitutionEvidenceExtractor
 from specfact_cli.generators.plan_generator import PlanGenerator
 from specfact_cli.generators.protocol_generator import ProtocolGenerator
 from specfact_cli.generators.workflow_generator import WorkflowGenerator
 from specfact_cli.importers.speckit_scanner import SpecKitScanner
+from specfact_cli.migrations.plan_migrator import get_current_schema_version
 from specfact_cli.models.plan import Feature, Idea, PlanBundle, Product, Release, Story
 from specfact_cli.models.protocol import Protocol
 from specfact_cli.utils.structure import SpecFactStructure
@@ -101,13 +103,16 @@ class SpecKitConverter:
 
     @beartype
     @ensure(lambda result: isinstance(result, PlanBundle), "Must return PlanBundle")
-    @ensure(lambda result: result.version == "1.0", "Must have version 1.0")
+    @ensure(
+        lambda result: result.version == get_current_schema_version(),
+        "Must have current schema version",
+    )
     def convert_plan(self, output_path: Path | None = None) -> PlanBundle:
         """
         Convert Spec-Kit markdown artifacts to SpecFact plan bundle.
 
         Args:
-            output_path: Optional path to write plan bundle (default: .specfact/plans/main.bundle.yaml)
+            output_path: Optional path to write plan bundle (default: .specfact/plans/main.bundle.<format>)
 
         Returns:
             Generated PlanBundle model
@@ -164,11 +169,14 @@ class SpecKitConverter:
 
         # Write to file if output path provided
         if output_path:
+            output_path = output_path.with_name(SpecFactStructure.ensure_plan_filename(output_path.name))
             SpecFactStructure.ensure_structure(output_path.parent)
             self.plan_generator.generate(plan_bundle, output_path)
         else:
-            # Use default path - construct .specfact/plans/main.bundle.yaml
-            output_path = self.repo_path / ".specfact" / "plans" / "main.bundle.yaml"
+            # Use default path respecting current output format
+            output_path = SpecFactStructure.get_default_plan_path(
+                base_path=self.repo_path, preferred_format=runtime.get_output_format()
+            )
             SpecFactStructure.ensure_structure(self.repo_path)
             self.plan_generator.generate(plan_bundle, output_path)
 
